@@ -38,6 +38,6 @@ rsquared_control <- as.matrix(read.csv("../fixtures/rsquared1.csv", row.names =
 
 test_that("Seminr estimates the Rsquared correctly", {
   # Remove BIC for now
-  expect_equal(rsquared[1:2,1], rsquared_control[1:2,1])
+  expect_equal(rsquared[1:2,1], rsquared_control[1:2,1], tolerance = 0.00001)
 })
 
